@@ -169,6 +169,9 @@ pref("accessibility.typeaheadfind.soundURL", "beep");
 pref("accessibility.typeaheadfind.enablesound", true);
 pref("accessibility.typeaheadfind.prefillwithselection", true);
 
+// use Mac OS X Appearance panel text smoothing setting when rendering text, disabled by default
+pref("gfx.use_text_smoothing_setting", false);
+
 pref("browser.history_expire_days", 9);
 
 // loading and rendering of framesets and iframes
@@ -520,7 +523,7 @@ pref("network.protocol-handler.external.data", false);
 pref("network.protocol-handler.external.ms-help", false);
 pref("network.protocol-handler.external.shell", false);
 pref("network.protocol-handler.external.vnd.ms.radio", false);
-//@line 529 "/export/home/mozilla/uild/firefox-nightly/src/mozilla/modules/libpref/src/init/all.js"
+//@line 532 "/export/home/mozilla/uild/firefox-nightly/src/mozilla/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.disk", false);
 pref("network.protocol-handler.external.disks", false);
 pref("network.protocol-handler.external.afp", false);
@@ -749,7 +752,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 763 "/export/home/mozilla/uild/firefox-nightly/src/mozilla/modules/libpref/src/init/all.js"
+//@line 766 "/export/home/mozilla/uild/firefox-nightly/src/mozilla/modules/libpref/src/init/all.js"
 
 // The following prefs are used to enable automatic use of the operating
 // system's NTLM implementation to silently authenticate the user with their
@@ -773,9 +776,9 @@ pref("network.hosts.nntp_server",           "news.mozilla.org");
 
 pref("permissions.default.image",           1); // 1-Accept, 2-Deny, 3-dontAcceptForeign
 
-//@line 788 "/export/home/mozilla/uild/firefox-nightly/src/mozilla/modules/libpref/src/init/all.js"
+//@line 791 "/export/home/mozilla/uild/firefox-nightly/src/mozilla/modules/libpref/src/init/all.js"
 pref("network.proxy.type",                  5);
-//@line 795 "/export/home/mozilla/uild/firefox-nightly/src/mozilla/modules/libpref/src/init/all.js"
+//@line 798 "/export/home/mozilla/uild/firefox-nightly/src/mozilla/modules/libpref/src/init/all.js"
 
 pref("network.proxy.ftp",                   "");
 pref("network.proxy.ftp_port",              0);
@@ -1109,15 +1112,15 @@ pref("font.minimum-size.x-western", 0);
 pref("font.minimum-size.x-unicode", 0);
 pref("font.minimum-size.x-user-def", 0);
 
-//@line 1511 "/export/home/mozilla/uild/firefox-nightly/src/mozilla/modules/libpref/src/init/all.js"
+//@line 1514 "/export/home/mozilla/uild/firefox-nightly/src/mozilla/modules/libpref/src/init/all.js"
 
-//@line 1927 "/export/home/mozilla/uild/firefox-nightly/src/mozilla/modules/libpref/src/init/all.js"
+//@line 1930 "/export/home/mozilla/uild/firefox-nightly/src/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2115 "/export/home/mozilla/uild/firefox-nightly/src/mozilla/modules/libpref/src/init/all.js"
+//@line 2127 "/export/home/mozilla/uild/firefox-nightly/src/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2206 "/export/home/mozilla/uild/firefox-nightly/src/mozilla/modules/libpref/src/init/all.js"
+//@line 2218 "/export/home/mozilla/uild/firefox-nightly/src/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2209 "/export/home/mozilla/uild/firefox-nightly/src/mozilla/modules/libpref/src/init/all.js"
+//@line 2221 "/export/home/mozilla/uild/firefox-nightly/src/mozilla/modules/libpref/src/init/all.js"
 // Handled differently under Mac/Windows
 pref("network.hosts.smtp_server", "localhost");
 pref("network.hosts.pop_server", "pop");
@@ -1371,20 +1374,20 @@ pref("print.postscript.paper_size",    "letter");
 pref("print.postscript.orientation",   "portrait");
 pref("print.postscript.print_command", "lpr ${MOZ_PRINTER_NAME:+-P\"$MOZ_PRINTER_NAME\"}");
 
-//@line 2465 "/export/home/mozilla/uild/firefox-nightly/src/mozilla/modules/libpref/src/init/all.js"
+//@line 2477 "/export/home/mozilla/uild/firefox-nightly/src/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2533 "/export/home/mozilla/uild/firefox-nightly/src/mozilla/modules/libpref/src/init/all.js"
+//@line 2545 "/export/home/mozilla/uild/firefox-nightly/src/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2559 "/export/home/mozilla/uild/firefox-nightly/src/mozilla/modules/libpref/src/init/all.js"
+//@line 2571 "/export/home/mozilla/uild/firefox-nightly/src/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2579 "/export/home/mozilla/uild/firefox-nightly/src/mozilla/modules/libpref/src/init/all.js"
+//@line 2591 "/export/home/mozilla/uild/firefox-nightly/src/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2581 "/export/home/mozilla/uild/firefox-nightly/src/mozilla/modules/libpref/src/init/all.js"
+//@line 2593 "/export/home/mozilla/uild/firefox-nightly/src/mozilla/modules/libpref/src/init/all.js"
 
 pref("print.postscript.print_command", "lp -c -s ${MOZ_PRINTER_NAME:+-d\"$MOZ_PRINTER_NAME\"}");
 pref("print.print_command", "lp -c -s ${MOZ_PRINTER_NAME:+-d\"$MOZ_PRINTER_NAME\"}");
 
-//@line 2587 "/export/home/mozilla/uild/firefox-nightly/src/mozilla/modules/libpref/src/init/all.js"
+//@line 2599 "/export/home/mozilla/uild/firefox-nightly/src/mozilla/modules/libpref/src/init/all.js"
 
 // Login Manager prefs
 pref("signon.rememberSignons",              true);
